@@ -2,6 +2,10 @@
 This script sets up self-defined errors.
 """
 
+import sys
+
+from .log import logger
+
 
 class ParsedNoneError(Exception):
     """Used when bs4 returned None whereas there's target content existing within the document"""
@@ -21,3 +25,12 @@ class NoResultError(Exception):
 
     def __str__(self):
         return self.message
+
+
+def call_on_error(error, url, attempt, op):
+    attempt += 1
+    logger.debug(f"{op} HTML from {url} {attempt} times - [ERROR] - {error}")
+    if attempt == 3:
+        logger.error(f"Maximum {op} retries reached. [ERROR] - {error}\nExit")
+        sys.exit()
+    return attempt
