@@ -1,6 +1,7 @@
 """
 This script sets up logger.
 """
+
 import logging
 
 # Logging only to stdout, not to local
@@ -11,9 +12,11 @@ logging.basicConfig(
     # filename=str(data / "dict.log"),
     # filemode="a",
     # format="%(asctime)s - %(pathname)s[line:%(lineno)d] - %(levelname)s: %(message)s",
-    format="%(asctime)s %(levelname)s %(message)s",
-    datefmt='%Y-%m-%d %H:%M:%S',
+    format="%(asctime)s %(levelname)s %(filename)s %(message)s",
+    datefmt="%Y-%m-%d %H:%M:%S",
     level=logging.INFO,
 )
 
-logger = logging.getLogger(__package__)
+logger = logging.getLogger(
+    __package__
+)  # if imported, all modules will have the same logger called by name of __package__'s value'
